==> wechat_assets_picker-8.1.1.tar.gz: test/widget_test.dart <==
//
// [Author] Alex (https://github.com/AlexV525)
// [Date] 2022/09/20 17:09
//

import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:wechat_assets_picker/wechat_assets_picker.dart';

import 'test_utils.dart';

void main() {
  PhotoManager.withPlugin(TestPhotoManagerPlugin());
  AssetPicker.setPickerDelegate(TestAssetPickerDelegate());

  group('Confirm button', () {
    group('displays when enabled preview', () {
      testWidgets(
        'with multiple assets picking',
        (WidgetTester tester) async {
          await tester.pumpWidget(
            defaultPickerTestApp(
              onButtonPressed: (BuildContext context) {
                AssetPicker.pickAssets(
                  context,
                  pickerConfig: const AssetPickerConfig(
                    maxAssets: 10,
                    // ignore: avoid_redundant_argument_values
                    specialPickerType: null, // Explicitly null.
                  ),
                );
              },
            ),
          );
          await tester.tap(defaultButtonFinder);
          await tester.pumpAndSettle();
          expect(
            find.text(const AssetPickerTextDelegate().confirm),
            findsOneWidget,
          );
        },
      );
      testWidgets(
        'with single asset picking',
        (WidgetTester tester) async {
          await tester.pumpWidget(
            defaultPickerTestApp(
              onButtonPressed: (BuildContext context) {
                AssetPicker.pickAssets(
                  context,
                  pickerConfig: const AssetPickerConfig(
                    maxAssets: 1,
                    // ignore: avoid_redundant_argument_values
                    specialPickerType: null, // Explicitly null.
                  ),
                );
              },
            ),
          );
          await tester.tap(defaultButtonFinder);
          await tester.pumpAndSettle();
          expect(
            find.text(const AssetPickerTextDelegate().confirm),
            findsOneWidget,
          );
        },
      );
    });

    testWidgets(
      'not display when disabled preview',
      (WidgetTester tester) async {
        await tester.pumpWidget(
          defaultPickerTestApp(
            onButtonPressed: (BuildContext context) {
              AssetPicker.pickAssets(
                context,
                pickerConfig: AssetPickerConfig(
                  specialPickerType: SpecialPickerType.noPreview,
                ),
              );
            },
          ),
        );
        await tester.tap(defaultButtonFinder);
        await tester.pumpAndSettle();
        expect(
          find.text(const AssetPickerTextDelegate().confirm),
          findsNothing,
        );
      },
    );
  });
}

==> wechat_assets_picker-8.4.2.tar.gz: test/widget_test.dart <==
//
// [Author] Alex (https://github.com/AlexV525)
// [Date] 2022/09/20 17:09
//

import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:wechat_assets_picker/wechat_assets_picker.dart';

import 'test_utils.dart';

void main() {
  PhotoManager.withPlugin(TestPhotoManagerPlugin());
  AssetPicker.setPickerDelegate(TestAssetPickerDelegate());

  group('Confirm button', () {
    group('when enabled preview', () {
      testWidgets('with multiple assets picking', (WidgetTester tester) async {
        await tester.pumpWidget(
          defaultPickerTestApp(
            onButtonPressed: (BuildContext context) {
              AssetPicker.pickAssets(
                context,
                pickerConfig: const AssetPickerConfig(
                  maxAssets: 10,
                  // ignore: avoid_redundant_argument_values
                  specialPickerType: null, // Explicitly null.
                ),
              );
            },
          ),
        );
        await tester.tap(defaultButtonFinder);
        await tester.pumpAndSettle();
        expect(
          find.text(const AssetPickerTextDelegate().confirm),
          findsOneWidget,
        );
      });
      testWidgets('with single asset picking', (WidgetTester tester) async {
        await tester.pumpWidget(
          defaultPickerTestApp(
            onButtonPressed: (BuildContext context) {
              AssetPicker.pickAssets(
                context,
                pickerConfig: const AssetPickerConfig(
                  maxAssets: 1,
                  // ignore: avoid_redundant_argument_values
                  specialPickerType: null, // Explicitly null.
                ),
              );
            },
          ),
        );
        await tester.tap(defaultButtonFinder);
        await tester.pumpAndSettle();
        expect(
          find.text(const AssetPickerTextDelegate().confirm),
          findsOneWidget,
        );
      });
    });
    group('when disabled preview', () {
      testWidgets('with multiple assets picker', (WidgetTester tester) async {
        await tester.pumpWidget(
          defaultPickerTestApp(
            onButtonPressed: (BuildContext context) {
              AssetPicker.pickAssets(
                context,
                pickerConfig: AssetPickerConfig(
                  maxAssets: 2,
                  specialPickerType: SpecialPickerType.noPreview,
                ),
              );
            },
          ),
        );
        await tester.tap(defaultButtonFinder);
        await tester.pumpAndSettle();
        expect(
          find.text(const AssetPickerTextDelegate().confirm),
          findsOneWidget,
        );
      });
      testWidgets('with single asset picker', (WidgetTester tester) async {
        await tester.pumpWidget(
          defaultPickerTestApp(
            onButtonPressed: (BuildContext context) {
              AssetPicker.pickAssets(
                context,
                pickerConfig: AssetPickerConfig(
                  maxAssets: 1,
                  specialPickerType: SpecialPickerType.noPreview,
                ),
              );
            },
          ),
        );
        await tester.tap(defaultButtonFinder);
        await tester.pumpAndSettle();
        expect(
          find.text(const AssetPickerTextDelegate().confirm),
          findsNothing,
        );
      });
    });
  });
}
